# $Id: HTTP.pm 36089 2011-11-23 19:23:06Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Error/HTTP.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Error::HTTP;

use Aselect::UI::Error -self;

field number;

sub type { 'http' }
sub args {
	return {
		number => $self->number,
		url => $self->req->url,
		page => $self->req->path_translated,
	}
}

sub response {
	my $res = super;
	$res->status($self->number);
	return $res;
}
